@@ -1,37 +1,38 @@
 /*
  * slmon
  *
- * Copyright (C) 2000 Krzysztof Luks <m00se@iq.pl>
- *
- * This program is based on WMMon.app.
- *
- * WMMon.app is copyright (c) 1997, 1998 by Martijn Pieterse and
- * Antoine Nulle.
+ * Copyright (C) 2000, 2001, 2002 Krzysztof Luks <m00se@iq.pl>
  *
  * This program is distributed under the GPL license. For details see
  * COPYING text.
  *
  * Author: Krzysztof Luks <m00se@iq.pl>
  *
+ * $Date: 2002/07/05 17:51:15 $
+ * $Revision: 1.11 $
+ *
  */
 
 #include "signal_handling.h"
 #include "defines.h"
 
+/*
+ * Things that need to be done before exiting
+ */
+
 void cleanup(int sig)
 {
-#ifdef HAVE_SLANG
     SLtt_set_cursor_visibility(1);
     SLang_reset_tty();
     SLsmg_reset_smg();
-#endif
-#ifdef HAVE_GTOP
-    glibtop_close()
-#endif
-	exit(sig);
+    glibtop_close();
+    exit(sig);
 }
 
-#ifdef HAVE_SLANG
+/*
+ * Signal handlers initialistion
+ */
+
 void init_signals(void)
 {
     SLsignal(SIGWINCH, handleSIGWINCH);
@@ -43,6 +44,10 @@ void init_signals(void)
     SLsignal(SIGSEGV, cleanup);
 }
 
+/*
+ * SIGWINCH handler: resize the display
+ */
+
 void handleSIGWINCH(int signal)
 {
     extern int redraw;
@@ -54,12 +59,12 @@ void handleSIGWINCH(int signal)
     SLtt_get_screen_size();
     SLsmg_cls();
 
-    draw_status();
-    clear_histogram();
     redraw = 1;
     pos = 0;
+    height = SLtt_Screen_Rows;
+    draw_status();
+    clear_histogram();
     SLsmg_refresh();
     SLsig_unblock_signals();
     SLsignal_intr(SIGWINCH, handleSIGWINCH);
 }
-#endif
